@@ -32,12 +32,10 @@ spec:
         name: node-ca
     spec:
       nodeSelector:
-        beta.kubernetes.io/os: linux
+        kubernetes.io/os: linux
       priorityClassName: system-cluster-critical
       tolerations:
-      - effect: NoSchedule
-        key: node-role.kubernetes.io/master
-        operator: Exists
+      - operator: Exists
       serviceAccountName: node-ca
       containers:
       - name: node-ca
