@@ -17,12 +17,13 @@ import (
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/wait"
 
+	configapiv1 "github.com/openshift/api/config/v1"
 	operatorapi "github.com/openshift/api/operator/v1"
 
 	imageregistryv1 "github.com/openshift/cluster-image-registry-operator/pkg/apis/imageregistry/v1"
 	regopclient "github.com/openshift/cluster-image-registry-operator/pkg/client"
-	"github.com/openshift/cluster-image-registry-operator/pkg/clusterconfig"
 	"github.com/openshift/cluster-image-registry-operator/pkg/storage"
+	storages3 "github.com/openshift/cluster-image-registry-operator/pkg/storage/s3"
 	"github.com/openshift/cluster-image-registry-operator/pkg/storage/util"
 	"github.com/openshift/cluster-image-registry-operator/test/framework"
 	"github.com/openshift/cluster-image-registry-operator/test/framework/mock/listers"
@@ -41,15 +42,16 @@ func TestAWSDefaults(t *testing.T) {
 	if err != nil {
 		t.Fatalf("Error building kubeconfig: %s", err)
 	}
+
 	newMockLister, err := listers.NewMockLister(kcfg)
 	mockLister, err := newMockLister.GetListers()
 
-	installConfig, err := clusterconfig.GetInstallConfig()
+	infra, err := util.GetInfrastructure(mockLister)
 	if err != nil {
 		t.Fatalf("unable to get install configuration: %v", err)
 	}
 
-	if installConfig.Platform.AWS == nil {
+	if infra.Status.PlatformStatus.Type != configapiv1.AWSPlatformType {
 		t.Skip("skipping on non-AWS platform")
 	}
 
@@ -65,7 +67,7 @@ func TestAWSDefaults(t *testing.T) {
 	framework.MustEnsureServiceCAConfigMap(t, client)
 	framework.MustEnsureNodeCADaemonSetIsAvailable(t, client)
 
-	cfg, err := clusterconfig.GetAWSConfig(mockLister)
+	cfg, err := storages3.GetConfig(kcfg, mockLister)
 	if err != nil {
 		t.Errorf("unable to get cluster configuration: %#v", err)
 	}
@@ -78,7 +80,7 @@ func TestAWSDefaults(t *testing.T) {
 	}
 	accessKey, _ := imageRegistryPrivateConfiguration.Data["REGISTRY_STORAGE_S3_ACCESSKEY"]
 	secretKey, _ := imageRegistryPrivateConfiguration.Data["REGISTRY_STORAGE_S3_SECRETKEY"]
-	if string(accessKey) != cfg.Storage.S3.AccessKey || string(secretKey) != cfg.Storage.S3.SecretKey {
+	if string(accessKey) != cfg.AccessKey || string(secretKey) != cfg.SecretKey {
 		t.Errorf("secret %s/%s contains incorrect aws credentials (AccessKey or SecretKey)", imageregistryv1.ImageRegistryOperatorNamespace, imageregistryv1.ImageRegistryPrivateConfiguration)
 	}
 
@@ -91,8 +93,8 @@ func TestAWSDefaults(t *testing.T) {
 	if cr.Spec.Storage.S3 == nil {
 		t.Errorf("custom resource %s/%s is missing the S3 configuration", imageregistryv1.ImageRegistryOperatorNamespace, imageregistryv1.ImageRegistryResourceName)
 	} else {
-		if cr.Spec.Storage.S3.Region != cfg.Storage.S3.Region {
-			t.Errorf("custom resource %s/%s contains incorrect data. S3 Region was %v but should have been %v", imageregistryv1.ImageRegistryOperatorNamespace, imageregistryv1.ImageRegistryResourceName, cfg.Storage.S3.Region, cr.Spec.Storage.S3)
+		if cr.Spec.Storage.S3.Region != cfg.Region {
+			t.Errorf("custom resource %s/%s contains incorrect data. S3 Region was %v but should have been %v", imageregistryv1.ImageRegistryOperatorNamespace, imageregistryv1.ImageRegistryResourceName, cfg.Region, cr.Spec.Storage.S3)
 
 		}
 		if cr.Spec.Storage.S3.Bucket == "" {
@@ -136,6 +138,14 @@ func TestAWSDefaults(t *testing.T) {
 		}
 	}
 
+	// Wait for the image registry resource to have an updated StoragePublicAccessBlocked condition
+	errs = framework.ConditionExistsWithStatusAndReason(client, imageregistryv1.StoragePublicAccessBlocked, operatorapi.ConditionTrue, "Public Access Block Successful")
+	if len(errs) != 0 {
+		for _, err := range errs {
+			t.Errorf("%#v", err)
+		}
+	}
+
 	// Check that the S3 bucket that we created exists and is accessible
 	sess, err := session.NewSession(&aws.Config{
 		Credentials: credentials.NewStaticCredentials(string(accessKey), string(secretKey), ""),
@@ -146,6 +156,7 @@ func TestAWSDefaults(t *testing.T) {
 	}
 
 	svc := s3.New(sess)
+
 	_, err = svc.HeadBucket(&s3.HeadBucketInput{
 		Bucket: aws.String(cr.Spec.Storage.S3.Bucket),
 	})
@@ -153,6 +164,29 @@ func TestAWSDefaults(t *testing.T) {
 		t.Errorf("s3 bucket %s does not exist or is inaccessible: %#v", cr.Spec.Storage.S3.Bucket, err)
 	}
 
+	// Check that the S3 bucket has the correct public access settings
+	getPublicAccessBlockResult, err := svc.GetPublicAccessBlock(&s3.GetPublicAccessBlockInput{
+		Bucket: aws.String(cr.Spec.Storage.S3.Bucket),
+	})
+	if err != nil {
+		t.Errorf("unable to get public access block information for s3 bucket: %#v", err)
+	}
+
+	gp := getPublicAccessBlockResult.PublicAccessBlockConfiguration
+
+	if gp.BlockPublicAcls == nil || !*gp.BlockPublicAcls {
+		t.Errorf("PublicAccessBlock.BlockPublicAcls should have been true, but was %#v instead", *gp.BlockPublicAcls)
+	}
+	if gp.BlockPublicPolicy == nil || !*gp.BlockPublicPolicy {
+		t.Errorf("PublicAccessBlock.BlockPublicPolicy should have been true, but was %#v instead", *gp.BlockPublicPolicy)
+	}
+	if gp.IgnorePublicAcls == nil || !*gp.IgnorePublicAcls {
+		t.Errorf("PublicAccessBlock.IgnorePublicAcls should have been true, but was %#v instead", *gp.IgnorePublicAcls)
+	}
+	if gp.RestrictPublicBuckets == nil || !*gp.RestrictPublicBuckets {
+		t.Errorf("PublicAccessBlock.RestrictPublicBuckets should have been true, but was %#v instead", *gp.RestrictPublicBuckets)
+	}
+
 	// Check that the S3 bucket has the correct tags
 	getBucketTaggingResult, err := svc.GetBucketTagging(&s3.GetBucketTaggingInput{
 		Bucket: aws.String(cr.Spec.Storage.S3.Bucket),
@@ -161,17 +195,10 @@ func TestAWSDefaults(t *testing.T) {
 		t.Errorf("unable to get tagging information for s3 bucket: %#v", err)
 	}
 
-	cv, err := util.GetClusterVersionConfig()
-	if err != nil {
-		t.Errorf("unable to get cluster version: %#v", err)
+	tagShouldExist := map[string]string{
+		"kubernetes.io/cluster/" + infra.Status.InfrastructureName: "owned",
 	}
 
-	tagShouldExist := map[string]string{
-		"openshiftClusterID": string(cv.Spec.ClusterID),
-	}
-	for k, v := range installConfig.Platform.AWS.UserTags {
-		tagShouldExist[k] = v
-	}
 	for tk, tv := range tagShouldExist {
 		found := false
 
@@ -311,19 +338,27 @@ func TestAWSDefaults(t *testing.T) {
 }
 
 func TestAWSUnableToCreateBucketOnStartup(t *testing.T) {
-	installConfig, err := clusterconfig.GetInstallConfig()
+	kubeconfig, err := regopclient.GetConfig()
+	if err != nil {
+		t.Fatalf("unable to get kubeconfig: %s", err)
+	}
+
+	newMockLister, err := listers.NewMockLister(kubeconfig)
+	mockLister, err := newMockLister.GetListers()
+
+	infra, err := util.GetInfrastructure(mockLister)
 	if err != nil {
 		t.Fatalf("unable to get install configuration: %v", err)
 	}
 
-	if installConfig.Platform.AWS == nil {
+	if infra.Status.PlatformStatus.Type != configapiv1.AWSPlatformType {
 		t.Skip("skipping on non-AWS platform")
 	}
 
 	client := framework.MustNewClientset(t, nil)
 
 	// Create the image-registry-private-configuration-user secret using the invalid credentials
-	if _, err := util.CreateOrUpdateSecret(imageregistryv1.ImageRegistryPrivateConfigurationUser, imageregistryv1.ImageRegistryOperatorNamespace, fakeAWSCredsData); err != nil {
+	if _, err := framework.CreateOrUpdateSecret(imageregistryv1.ImageRegistryPrivateConfigurationUser, imageregistryv1.ImageRegistryOperatorNamespace, fakeAWSCredsData); err != nil {
 		t.Fatalf("unable to create secret %q: %#v", fmt.Sprintf("%s/%s", imageregistryv1.ImageRegistryOperatorNamespace, imageregistryv1.ImageRegistryPrivateConfigurationUser), err)
 	}
 
@@ -362,15 +397,16 @@ func TestAWSUpdateCredentials(t *testing.T) {
 	if err != nil {
 		t.Fatalf("Error building kubeconfig: %s", err)
 	}
+
 	newMockLister, err := listers.NewMockLister(kcfg)
 	mockLister, err := newMockLister.GetListers()
 
-	installConfig, err := clusterconfig.GetInstallConfig()
+	infra, err := util.GetInfrastructure(mockLister)
 	if err != nil {
 		t.Fatalf("unable to get install configuration: %v", err)
 	}
 
-	if installConfig.Platform.AWS == nil {
+	if infra.Status.PlatformStatus.Type != configapiv1.AWSPlatformType {
 		t.Skip("skipping on non-AWS platform")
 	}
 
@@ -384,7 +420,7 @@ func TestAWSUpdateCredentials(t *testing.T) {
 
 	// Create the image-registry-private-configuration-user secret using the invalid credentials
 	err = wait.PollImmediate(1*time.Second, framework.AsyncOperationTimeout, func() (stop bool, err error) {
-		if _, err := util.CreateOrUpdateSecret(imageregistryv1.ImageRegistryPrivateConfigurationUser, imageregistryv1.ImageRegistryOperatorNamespace, fakeAWSCredsData); err != nil {
+		if _, err := framework.CreateOrUpdateSecret(imageregistryv1.ImageRegistryPrivateConfigurationUser, imageregistryv1.ImageRegistryOperatorNamespace, fakeAWSCredsData); err != nil {
 			t.Logf("unable to create secret: %s", err)
 			return false, nil
 		}
@@ -395,11 +431,11 @@ func TestAWSUpdateCredentials(t *testing.T) {
 	}
 
 	// Check that the user provided credentials override the system provided ones
-	cfgUser, err := clusterconfig.GetAWSConfig(mockLister)
+	cfgUser, err := storages3.GetConfig(kcfg, mockLister)
 	if err != nil {
 		t.Errorf("unable to get aws configuration: %#v", err)
 	}
-	if fakeAWSCredsData["REGISTRY_STORAGE_S3_ACCESSKEY"] != cfgUser.Storage.S3.AccessKey || fakeAWSCredsData["REGISTRY_STORAGE_S3_SECRETKEY"] != cfgUser.Storage.S3.SecretKey {
+	if fakeAWSCredsData["REGISTRY_STORAGE_S3_ACCESSKEY"] != cfgUser.AccessKey || fakeAWSCredsData["REGISTRY_STORAGE_S3_SECRETKEY"] != cfgUser.SecretKey {
 		t.Errorf("expected system configuration to be overridden by the user configuration but it wasn't.")
 	}
 
@@ -431,12 +467,20 @@ func TestAWSUpdateCredentials(t *testing.T) {
 }
 
 func TestAWSChangeS3Encryption(t *testing.T) {
-	installConfig, err := clusterconfig.GetInstallConfig()
+	kubeconfig, err := regopclient.GetConfig()
+	if err != nil {
+		t.Fatalf("unable to get kubeconfig: %s", err)
+	}
+
+	newMockLister, err := listers.NewMockLister(kubeconfig)
+	mockLister, err := newMockLister.GetListers()
+
+	infra, err := util.GetInfrastructure(mockLister)
 	if err != nil {
 		t.Fatalf("unable to get install configuration: %v", err)
 	}
 
-	if installConfig.Platform.AWS == nil {
+	if infra.Status.PlatformStatus.Type != configapiv1.AWSPlatformType {
 		t.Skip("skipping on non-AWS platform")
 	}
 
@@ -614,15 +658,16 @@ func TestAWSFinalizerDeleteS3Bucket(t *testing.T) {
 	if err != nil {
 		t.Fatalf("Error building kubeconfig: %s", err)
 	}
+
 	newMockLister, err := listers.NewMockLister(kcfg)
 	mockLister, err := newMockLister.GetListers()
 
-	installConfig, err := clusterconfig.GetInstallConfig()
+	infra, err := util.GetInfrastructure(mockLister)
 	if err != nil {
 		t.Fatalf("unable to get install configuration: %v", err)
 	}
 
-	if installConfig.Platform.AWS == nil {
+	if infra.Status.PlatformStatus.Type != configapiv1.AWSPlatformType {
 		t.Skip("skipping on non-AWS platform")
 	}
 
@@ -643,7 +688,7 @@ func TestAWSFinalizerDeleteS3Bucket(t *testing.T) {
 	if err != nil {
 		t.Errorf("unable to get image registry resource: %#v", err)
 	}
-	driver, err := storage.NewDriver(&cr.Spec.Storage, mockLister)
+	driver, err := storage.NewDriver(&cr.Spec.Storage, kcfg, mockLister)
 	if err != nil {
 		t.Fatal("unable to create new s3 driver")
 	}
